@@ -2,6 +2,7 @@ import copy
 import pandas as pd
 import numpy as np
 import warnings
+import logging
 
 from supervised.preprocessing.preprocessing_utils import PreprocessingUtils
 from supervised.preprocessing.preprocessing_categorical import PreprocessingCategorical
@@ -20,9 +21,8 @@ from supervised.algorithms.registry import (
     MULTICLASS_CLASSIFICATION,
     REGRESSION,
 )
-
-import logging
 from supervised.utils.config import LOG_LEVEL
+from supervised.exceptions import AutoMLException
 
 logger = logging.getLogger(__name__)
 logger.setLevel(LOG_LEVEL)
@@ -131,7 +131,7 @@ class Preprocessing(object):
             X_train.drop(cols_to_remove, axis=1, inplace=True)
         self._remove_columns = cols_to_remove
 
-        numeric_cols = [] # get numeric cols before text transformations
+        numeric_cols = []  # get numeric cols before text transformations
         # needed for golden features
         if X_train is not None and "golden_features" in self._params:
             numeric_cols = X_train.select_dtypes(include="number").columns.tolist()
@@ -251,6 +251,10 @@ class Preprocessing(object):
         if self._drop_features:
             available_cols = X_train.columns.tolist()
             drop_cols = [c for c in self._drop_features if c in available_cols]
+            if len(drop_cols) == X_train.shape[1]:
+                raise AutoMLException(
+                    "All features are droppped! Your data looks like random data."
+                )
             if drop_cols:
                 X_train.drop(drop_cols, axis=1, inplace=True)
             self._drop_features = drop_cols
@@ -327,13 +331,14 @@ class Preprocessing(object):
         ):
             # there is something missing, fill it
             # we should notice user about it!
-            warnings.warn(
-                "There are columns {} with missing values which didnt have missing values in train dataset.".format(
-                    list(
-                        X_validation.columns[np.where(np.sum(pd.isnull(X_validation)))]
-                    )
-                )
-            )
+            # warnings should go to the separate file ...
+            # warnings.warn(
+            #    "There are columns {} with missing values which didnt have missing values in train dataset.".format(
+            #        list(
+            #            X_validation.columns[np.where(np.sum(pd.isnull(X_validation)))]
+            #        )
+            #    )
+            # )
             missing = PreprocessingMissingValues(
                 X_validation.columns, PreprocessingMissingValues.FILL_NA_MEDIAN
             )
@@ -527,10 +532,14 @@ class Preprocessing(object):
         if self._drop_features:
             preprocessing_params["drop_features"] = self._drop_features
 
+        preprocessing_params["params"] = self._params
+
         return preprocessing_params
 
     def from_json(self, data_json):
 
+        self._params = data_json.get("params", self._params)
+
         if "remove_columns" in data_json:
             self._remove_columns = data_json.get("remove_columns", [])
         if "missing_values" in data_json:
